@@ -5,7 +5,6 @@
 
 #include "plugin.h"
 
-void mupdf_page_extract_text(mupdf_document_t* mupdf_document,
-    mupdf_page_t* mupdf_page);
+void mupdf_page_extract_text(mupdf_document_t* mupdf_document, mupdf_page_t* mupdf_page);
 
 #endif // UTILS_H
